import pytest
from inventory_provider.routes import classifier
from inventory_provider.routes.classifier import get_top_level_services
from inventory_provider.tasks import common


@pytest.mark.parametrize('interface_name,base_name', [
    ('ae0', 'ae0'),
    ('ae0.0', 'ae0'),
    ('ae1.0', 'ae1'),
    ('ae10.2603', 'ae10'),
    ('et-3/1/2', 'et-3/1/2'),
    ('et-3/1/2.100', 'et-3/1/2'),
    ('xe-2/1/0', 'xe-2/1/0'),
    ('xe-2/1/0.933', 'xe-2/1/0'),

    # degenerate cases ... check expected regex behavior
    ('xe-2/1/0.933.933', 'xe-2/1/0.933'),
    (' sss.333.aaa ', ' sss.333.aaa '),
    (' sss.333.aaa .999', ' sss.333.aaa ')
]
)
def test_base_interface_name(interface_name, base_name):
    assert classifier.base_interface_name(interface_name) == base_name


# todo - not too keen on this as it relies on the extracted opsdb data, which
#        could change and lead to this test failing
def test_get_top_level_circuits(mocked_redis):
    config = {
        'redis-databases': 'xxx',
        'redis': {
            'hostname': 'host',
            'port': 1234
        }
    }
    r = common.get_current_redis(config)
    tls = get_top_level_services(47141, r)
    assert len(tls) == 1
    assert tls[0]['name'] == 'LON2-PAR 300G TRUNK'
